==> haskell-xml-conduit-1.9.1.4-117-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-xml-conduit.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 xml-conduit
version:              1.9.1.4
visibility:           public
id:                   xml-conduit-1.9.1.4-ClYmWYtZnVGBt5jjOED7ry
key:                  xml-conduit-1.9.1.4-ClYmWYtZnVGBt5jjOED7ry
license:              MIT
maintainer:           Michael Snoyman <michael@snoyman.com>
author:
    Michael Snoyman <michael@snoyman.com>, Aristid Breitkreuz <aristidb@googlemail.com>

stability:            Stable
homepage:             http://github.com/snoyberg/xml
synopsis:
    Pure-Haskell utilities for dealing with XML with the conduit package.

description:
    Hackage documentation generation is not reliable. For up to date documentation, please see: <http://www.stackage.org/package/xml-conduit>.

category:             XML, Conduit
abi:                  e707d795475ef71a5aa7729919d67182
exposed:              True
exposed-modules:
    Text.XML Text.XML.Cursor Text.XML.Cursor.Generic
    Text.XML.Stream.Parse Text.XML.Stream.Render Text.XML.Unresolved

hidden-modules:       Text.XML.Stream.Token
import-dirs:          /usr/lib/ghc-9.4.8/site-local/xml-conduit-1.9.1.4
library-dirs:         /usr/lib/ghc-9.4.8/site-local/xml-conduit-1.9.1.4
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/xml-conduit-1.9.1.4
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-xml-conduit
hs-libraries:         HSxml-conduit-1.9.1.4-ClYmWYtZnVGBt5jjOED7ry
depends:
    attoparsec-0.14.4-IxPlyKeM7RE2Q1eOkxwOEV base-4.17.2.1
    blaze-html-0.9.2.0-97pJC8dBTXf5qZAc9J115X
    blaze-markup-0.8.3.0-FXydca45yHzIHzHIuN3fo7 bytestring-0.11.5.3
    conduit-1.3.6.1-7gDrgQT36z4IN6MqKXM4jU
    conduit-extra-1.3.8-LH0nSmNEDBz6QpPwrMyaiE containers-0.6.7
    data-default-0.7.1.2-2qohbnSvS9oK93FFGOJ5gM deepseq-1.4.8.0
    resourcet-1.2.6-2BcDKwHjSabK2j2MMy69bs text-2.0.2
    transformers-0.5.6.2 xml-types-0.3.8-IpGyuvvNOu2AH1SOobl25

haddock-interfaces:   /usr/share/doc/haskell-xml-conduit/html/xml-conduit.haddock
haddock-html:         /usr/share/doc/haskell-xml-conduit/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-xml-conduit-1.9.1.4-118-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-xml-conduit.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 xml-conduit
version:              1.9.1.4
visibility:           public
id:                   xml-conduit-1.9.1.4-8jMCVYgOSZmIGo2E72CuSe
key:                  xml-conduit-1.9.1.4-8jMCVYgOSZmIGo2E72CuSe
license:              MIT
maintainer:           Michael Snoyman <michael@snoyman.com>
author:
    Michael Snoyman <michael@snoyman.com>, Aristid Breitkreuz <aristidb@googlemail.com>

stability:            Stable
homepage:             http://github.com/snoyberg/xml
synopsis:
    Pure-Haskell utilities for dealing with XML with the conduit package.

description:
    Hackage documentation generation is not reliable. For up to date documentation, please see: <http://www.stackage.org/package/xml-conduit>.

category:             XML, Conduit
abi:                  662711328ca537b1cacb2b71bd6894e2
exposed:              True
exposed-modules:
    Text.XML Text.XML.Cursor Text.XML.Cursor.Generic
    Text.XML.Stream.Parse Text.XML.Stream.Render Text.XML.Unresolved

hidden-modules:       Text.XML.Stream.Token
import-dirs:          /usr/lib/ghc-9.4.8/site-local/xml-conduit-1.9.1.4
library-dirs:         /usr/lib/ghc-9.4.8/site-local/xml-conduit-1.9.1.4
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/xml-conduit-1.9.1.4
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-xml-conduit
hs-libraries:         HSxml-conduit-1.9.1.4-8jMCVYgOSZmIGo2E72CuSe
depends:
    attoparsec-0.14.4-6kRuW0kw4gG3rg1QrsDffs base-4.17.2.1
    blaze-html-0.9.2.0-GSQGyEfgR96HA14H2zM96E
    blaze-markup-0.8.3.0-L6t6v2gy37n7wxr3axaBPf bytestring-0.11.5.3
    conduit-1.3.6.1-P2VVzWMvOMICi7Nj7BTmx
    conduit-extra-1.3.8-4zxXchcBeveL56hfIzolRA containers-0.6.7
    data-default-0.7.1.2-434WfftxN7fJEVVCTZ9w4g deepseq-1.4.8.0
    resourcet-1.2.6-9XnyFw86jRf1sw1PLhkl5l text-2.0.2
    transformers-0.5.6.2 xml-types-0.3.8-IpGyuvvNOu2AH1SOobl25

haddock-interfaces:   /usr/share/doc/haskell-xml-conduit/html/xml-conduit.haddock
haddock-html:         /usr/share/doc/haskell-xml-conduit/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
